Struct oci_spec::image::History[][src]

pub struct History {
    pub created: Option<String>,
    pub author: Option<String>,
    pub created_by: Option<String>,
    pub comment: Option<String>,
    pub empty_layer: Option<bool>,
}
Describes the history of a layer.

Fields

created: Option<String>

A combined date and time at which the layer was created, formatted as defined by RFC 3339, section 5.6..

author: Option<String>

The author of the build point.

created_by: Option<String>

The command which created the layer.

comment: Option<String>

A custom message set when creating the layer.

empty_layer: Option<bool>

This field is used to mark if the history item created a filesystem diff. It is set to true if this history item doesn’t correspond to an actual layer in the rootfs section