Struct oci_spec::image::Platform [−][src]
pub struct Platform {
pub architecture: String,
pub os: String,
pub os_version: Option<String>,
pub os_features: Option<Vec<String>>,
pub variant: Option<String>,
}Expand description
Describes the minimum runtime requirements of the image.
Fields
architecture: StringThis REQUIRED property specifies the CPU architecture. Image indexes SHOULD use, and implementations SHOULD understand, values listed in the Go Language document for GOARCH.
os: StringThis REQUIRED property specifies the operating system. Image indexes SHOULD use, and implementations SHOULD understand, values listed in the Go Language document for GOOS.
os_version: Option<String>This OPTIONAL property specifies the version of the operating system targeted by the referenced blob. Implementations MAY refuse to use manifests where os.version is not known to work with the host OS version. Valid values are implementation-defined. e.g. 10.0.14393.1066 on windows.
os_features: Option<Vec<String>>This OPTIONAL property specifies an array of strings, each specifying a mandatory OS feature. When os is windows, image indexes SHOULD use, and implementations SHOULD understand the following values:
- win32k: image requires win32k.sys on the host (Note: win32k.sys is missing on Nano Server)
When os is not windows, values are implementation-defined and SHOULD be submitted to this specification for standardization.
variant: Option<String>This OPTIONAL property specifies the variant of the CPU. Image indexes SHOULD use, and implementations SHOULD understand, variant values listed in the [Platform Variants] (https://github.com/opencontainers/image-spec/blob/main/image-index.md#platform-variants) table.