#[repr(u32)]pub enum Arch {
Show 24 variants
ScmpArchNative = 0,
ScmpArchX86 = 1_073_741_827,
ScmpArchX86_64 = 3_221_225_534,
ScmpArchX32 = 1_073_741_886,
ScmpArchArm = 1_073_741_864,
ScmpArchAarch64 = 3_221_225_655,
ScmpArchMips = 8,
ScmpArchMips64 = 2_147_483_656,
ScmpArchMips64n32 = 2_684_354_568,
ScmpArchMipsel = 1_073_741_832,
ScmpArchMipsel64 = 3_221_225_480,
ScmpArchMipsel64n32 = 3_758_096_392,
ScmpArchPpc = 20,
ScmpArchPpc64 = 2_147_483_669,
ScmpArchPpc64le = 3_221_225_493,
ScmpArchS390 = 22,
ScmpArchS390x = 2_147_483_670,
ScmpArchParisc = 15,
ScmpArchParisc64 = 2_147_483_663,
ScmpArchRiscv64 = 3_221_225_715,
ScmpArchLoongarch64 = 3_221_225_730,
ScmpArchM68k = 4,
ScmpArchSh = 1_073_741_866,
ScmpArchSheb = 42,
}Expand description
Available seccomp architectures.
Variants
ScmpArchNative = 0
The native architecture.
ScmpArchX86 = 1_073_741_827
The x86 (32-bit) architecture.
ScmpArchX86_64 = 3_221_225_534
The x86-64 (64-bit) architecture.
ScmpArchX32 = 1_073_741_886
The x32 (32-bit x86_64) architecture.
This is different from the value used by the kernel because we need to be able to distinguish between x32 and x86_64.
ScmpArchArm = 1_073_741_864
The ARM architecture.
ScmpArchAarch64 = 3_221_225_655
The AArch64 architecture.
ScmpArchMips = 8
The MIPS architecture.
ScmpArchMips64 = 2_147_483_656
The MIPS64 architecture.
ScmpArchMips64n32 = 2_684_354_568
The MIPS64n32 architecture.
ScmpArchMipsel = 1_073_741_832
The MIPSel architecture.
ScmpArchMipsel64 = 3_221_225_480
The MIPSel64 architecture.
ScmpArchMipsel64n32 = 3_758_096_392
The MIPSel64n32 architecture.
ScmpArchPpc = 20
The PowerPC architecture.
ScmpArchPpc64 = 2_147_483_669
The PowerPC64 architecture.
ScmpArchPpc64le = 3_221_225_493
The PowerPC64le architecture.
ScmpArchS390 = 22
The S390 architecture.
ScmpArchS390x = 2_147_483_670
The S390x architecture.
ScmpArchParisc = 15
The PA-RISC architecture.
ScmpArchParisc64 = 2_147_483_663
The PA-RISC64 architecture.
ScmpArchRiscv64 = 3_221_225_715
The RISCV64 architecture.
ScmpArchLoongarch64 = 3_221_225_730
The LoongArch64 architecture.
ScmpArchM68k = 4
The Motorola 68000 (32-bit) architecture.
ScmpArchSh = 1_073_741_866
The SuperH (32-bit) architecture.
ScmpArchSheb = 42
The SuperH (32-bit, big-endian) architecture.