pub struct ContainerProcessStateBuilder { /* private fields */ }Expand description
Builder for ContainerProcessState.
Implementations
Sourceimpl ContainerProcessStateBuilder
impl ContainerProcessStateBuilder
Sourcepub fn version<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn version<VALUE: Into<String>>(self, value: VALUE) -> Self
version is the version of the specification that is supported.
Sourcepub fn fds<VALUE: Into<Vec<String>>>(self, value: VALUE) -> Self
pub fn fds<VALUE: Into<Vec<String>>>(self, value: VALUE) -> Self
fds is a string array containing the names of the file descriptors passed.
The index of the name in this array corresponds to index of the file
descriptor in the SCM_RIGHTS array.
Sourcepub fn pid<VALUE: Into<i32>>(self, value: VALUE) -> Self
pub fn pid<VALUE: Into<i32>>(self, value: VALUE) -> Self
pid is the process ID as seen by the runtime.
Sourcepub fn build(self) -> Result<ContainerProcessState, OciSpecError>
pub fn build(self) -> Result<ContainerProcessState, OciSpecError>