pub struct LinuxBlockIo { /* private fields */ }
LinuxBlockIO for Linux cgroup ‘blkio’ resource management.

Implementations

source

impl LinuxBlockIo

source

pub fn weight(&self) -> Option<u16>

Specifies per cgroup weight.

source

pub fn leaf_weight(&self) -> Option<u16>

Specifies tasks’ weight in the given cgroup while competing with the cgroup’s child cgroups, CFQ scheduler only.

source

impl LinuxBlockIo

source

pub fn weight_device(&self) -> &Option<Vec<LinuxWeightDevice>>

Weight per cgroup per device, can override BlkioWeight.

source

pub fn throttle_read_bps_device(&self) -> &Option<Vec<LinuxThrottleDevice>>

IO read rate limit per cgroup per device, bytes per second.

source

pub fn throttle_write_bps_device(&self) -> &Option<Vec<LinuxThrottleDevice>>

IO write rate limit per cgroup per device, bytes per second.

source

pub fn throttle_read_iops_device(&self) -> &Option<Vec<LinuxThrottleDevice>>

IO read rate limit per cgroup per device, IO per second.

source

pub fn throttle_write_iops_device(&self) -> &Option<Vec<LinuxThrottleDevice>>

IO write rate limit per cgroup per device, IO per second.

source

impl LinuxBlockIo

source

pub fn set_weight(&mut self, val: Option<u16>) -> &mut Self

Specifies per cgroup weight.

source

pub fn set_leaf_weight(&mut self, val: Option<u16>) -> &mut Self

Specifies tasks’ weight in the given cgroup while competing with the cgroup’s child cgroups, CFQ scheduler only.

source

pub fn set_weight_device( &mut self, val: Option<Vec<LinuxWeightDevice>> ) -> &mut Self

Weight per cgroup per device, can override BlkioWeight.

source

pub fn set_throttle_read_bps_device( &mut self, val: Option<Vec<LinuxThrottleDevice>> ) -> &mut Self

IO read rate limit per cgroup per device, bytes per second.

source

pub fn set_throttle_write_bps_device( &mut self, val: Option<Vec<LinuxThrottleDevice>> ) -> &mut Self

IO write rate limit per cgroup per device, bytes per second.

source

pub fn set_throttle_read_iops_device( &mut self, val: Option<Vec<LinuxThrottleDevice>> ) -> &mut Self

IO read rate limit per cgroup per device, IO per second.

source

pub fn set_throttle_write_iops_device( &mut self, val: Option<Vec<LinuxThrottleDevice>> ) -> &mut Self

IO write rate limit per cgroup per device, IO per second.