pub struct LinuxCapabilities { /* private fields */ }
LinuxCapabilities specifies the list of allowed capabilities that are kept for a process. http://man7.org/linux/man-pages/man7/capabilities.7.html

Implementations

source

impl LinuxCapabilities

source

pub fn bounding(&self) -> &Option<Capabilities>

Bounding is the set of capabilities checked by the kernel.

source

pub fn effective(&self) -> &Option<Capabilities>

Effective is the set of capabilities checked by the kernel.

source

pub fn inheritable(&self) -> &Option<Capabilities>

Inheritable is the capabilities preserved across execve.

source

pub fn permitted(&self) -> &Option<Capabilities>

Permitted is the limiting superset for effective capabilities.

source

pub fn ambient(&self) -> &Option<Capabilities>

Ambient is the ambient set of capabilities that are kept.

source

impl LinuxCapabilities

source

pub fn set_bounding(&mut self, val: Option<Capabilities>) -> &mut Self

Bounding is the set of capabilities checked by the kernel.

source

pub fn set_effective(&mut self, val: Option<Capabilities>) -> &mut Self

Effective is the set of capabilities checked by the kernel.

source

pub fn set_inheritable(&mut self, val: Option<Capabilities>) -> &mut Self

Inheritable is the capabilities preserved across execve.

source

pub fn set_permitted(&mut self, val: Option<Capabilities>) -> &mut Self

Permitted is the limiting superset for effective capabilities.

source

pub fn set_ambient(&mut self, val: Option<Capabilities>) -> &mut Self

Ambient is the ambient set of capabilities that are kept.