Struct oci_spec::runtime::LinuxCpu

source ·
pub struct LinuxCpu { /* private fields */ }
LinuxCPU for Linux cgroup ‘cpu’ resource management.

Implementations

source

impl LinuxCpu

source

pub fn shares(&self) -> Option<u64>

CPU shares (relative weight (ratio) vs. other cgroups with cpu shares).

source

pub fn quota(&self) -> Option<i64>

CPU hardcap limit (in usecs). Allowed cpu time in a given period.

source

pub fn idle(&self) -> Option<i64>

Cgroups are configured with minimum weight, 0: default behavior, 1: SCHED_IDLE.

source

pub fn burst(&self) -> Option<u64>

Maximum amount of accumulated time in microseconds for which tasks in a cgroup can run additionally for burst during one period

source

pub fn period(&self) -> Option<u64>

CPU period to be used for hardcapping (in usecs).

source

pub fn realtime_runtime(&self) -> Option<i64>

How much time realtime scheduling may use (in usecs).

source

pub fn realtime_period(&self) -> Option<u64>

CPU period to be used for realtime scheduling (in usecs).

source

impl LinuxCpu

source

pub fn cpus(&self) -> &Option<String>

CPUs to use within the cpuset. Default is to use any CPU available.

source

pub fn mems(&self) -> &Option<String>

List of memory nodes in the cpuset. Default is to use any available memory node.

source

impl LinuxCpu

source

pub fn set_shares(&mut self, val: Option<u64>) -> &mut Self

CPU shares (relative weight (ratio) vs. other cgroups with cpu shares).

source

pub fn set_quota(&mut self, val: Option<i64>) -> &mut Self

CPU hardcap limit (in usecs). Allowed cpu time in a given period.

source

pub fn set_idle(&mut self, val: Option<i64>) -> &mut Self

Cgroups are configured with minimum weight, 0: default behavior, 1: SCHED_IDLE.

source

pub fn set_burst(&mut self, val: Option<u64>) -> &mut Self

Maximum amount of accumulated time in microseconds for which tasks in a cgroup can run additionally for burst during one period

source

pub fn set_period(&mut self, val: Option<u64>) -> &mut Self

CPU period to be used for hardcapping (in usecs).

source

pub fn set_realtime_runtime(&mut self, val: Option<i64>) -> &mut Self

How much time realtime scheduling may use (in usecs).

source

pub fn set_realtime_period(&mut self, val: Option<u64>) -> &mut Self

CPU period to be used for realtime scheduling (in usecs).

source

pub fn set_cpus(&mut self, val: Option<String>) -> &mut Self

CPUs to use within the cpuset. Default is to use any CPU available.

source

pub fn set_mems(&mut self, val: Option<String>) -> &mut Self

List of memory nodes in the cpuset. Default is to use any available memory node.