pub struct LinuxNamespace { /* private fields */ }
LinuxNamespace is the configuration for a Linux namespace.

Implementations

source

impl LinuxNamespace

source

pub fn typ(&self) -> LinuxNamespaceType

Type is the type of namespace.

source

impl LinuxNamespace

source

pub fn path(&self) -> &Option<PathBuf>

Path is a path to an existing namespace persisted on disk that can be joined and is of the same type

source

impl LinuxNamespace

source

pub fn set_typ(&mut self, val: LinuxNamespaceType) -> &mut Self

Type is the type of namespace.

source

pub fn set_path(&mut self, val: Option<PathBuf>) -> &mut Self

Path is a path to an existing namespace persisted on disk that can be joined and is of the same type