pub struct LinuxResources { /* private fields */ }
Resource constraints for container

Implementations

source

impl LinuxResources

source

pub fn devices(&self) -> &Option<Vec<LinuxDeviceCgroup>>

Devices configures the device allowlist.

source

pub fn memory(&self) -> &Option<LinuxMemory>

Memory restriction configuration.

source

pub fn cpu(&self) -> &Option<LinuxCpu>

CPU resource restriction configuration.

source

pub fn pids(&self) -> &Option<LinuxPids>

Task resource restrictions

source

pub fn block_io(&self) -> &Option<LinuxBlockIo>

BlockIO restriction configuration.

source

pub fn hugepage_limits(&self) -> &Option<Vec<LinuxHugepageLimit>>

Hugetlb limit (in bytes).

source

pub fn network(&self) -> &Option<LinuxNetwork>

Network restriction configuration.

source

pub fn rdma(&self) -> &Option<HashMap<String, LinuxRdma>>

Rdma resource restriction configuration. Limits are a set of key value pairs that define RDMA resource limits, where the key is device name and value is resource limits.

source

pub fn unified(&self) -> &Option<HashMap<String, String>>

Unified resources.

source

impl LinuxResources

source

pub fn set_devices(&mut self, val: Option<Vec<LinuxDeviceCgroup>>) -> &mut Self

Devices configures the device allowlist.

source

pub fn set_memory(&mut self, val: Option<LinuxMemory>) -> &mut Self

Memory restriction configuration.

source

pub fn set_cpu(&mut self, val: Option<LinuxCpu>) -> &mut Self

CPU resource restriction configuration.

source

pub fn set_pids(&mut self, val: Option<LinuxPids>) -> &mut Self

Task resource restrictions

source

pub fn set_block_io(&mut self, val: Option<LinuxBlockIo>) -> &mut Self

BlockIO restriction configuration.

source

pub fn set_hugepage_limits( &mut self, val: Option<Vec<LinuxHugepageLimit>> ) -> &mut Self

Hugetlb limit (in bytes).

source

pub fn set_network(&mut self, val: Option<LinuxNetwork>) -> &mut Self

Network restriction configuration.

source

pub fn set_rdma(&mut self, val: Option<HashMap<String, LinuxRdma>>) -> &mut Self

Rdma resource restriction configuration. Limits are a set of key value pairs that define RDMA resource limits, where the key is device name and value is resource limits.

source

pub fn set_unified(&mut self, val: Option<HashMap<String, String>>) -> &mut Self

Unified resources.