pub struct LinuxSeccomp { /* private fields */ }
LinuxSeccomp represents syscall restrictions.

Implementations

source

impl LinuxSeccomp

source

pub fn default_action(&self) -> LinuxSeccompAction

The default action to be done.

source

pub fn default_errno_ret(&self) -> Option<u32>

The default error return code to use when the default action is SCMP_ACT_ERRNO.

source

impl LinuxSeccomp

source

pub fn architectures(&self) -> &Option<Vec<Arch>>

Available architectures for the restriction.

source

pub fn flags(&self) -> &Option<Vec<LinuxSeccompFilterFlag>>

Flags added to the seccomp restriction.

source

pub fn listener_path(&self) -> &Option<PathBuf>

The unix domain socket path over which runtime will use for SCMP_ACT_NOTIFY.

source

pub fn listener_metadata(&self) -> &Option<String>

An opaque data to pass to the seccomp agent.

source

pub fn syscalls(&self) -> &Option<Vec<LinuxSyscall>>

The syscalls for the restriction.

source

impl LinuxSeccomp

source

pub fn set_default_action(&mut self, val: LinuxSeccompAction) -> &mut Self

The default action to be done.

source

pub fn set_default_errno_ret(&mut self, val: Option<u32>) -> &mut Self

The default error return code to use when the default action is SCMP_ACT_ERRNO.

source

pub fn set_architectures(&mut self, val: Option<Vec<Arch>>) -> &mut Self

Available architectures for the restriction.

source

pub fn set_flags( &mut self, val: Option<Vec<LinuxSeccompFilterFlag>> ) -> &mut Self

Flags added to the seccomp restriction.

source

pub fn set_listener_path(&mut self, val: Option<PathBuf>) -> &mut Self

The unix domain socket path over which runtime will use for SCMP_ACT_NOTIFY.

source

pub fn set_listener_metadata(&mut self, val: Option<String>) -> &mut Self

An opaque data to pass to the seccomp agent.

source

pub fn set_syscalls(&mut self, val: Option<Vec<LinuxSyscall>>) -> &mut Self

The syscalls for the restriction.