Struct oci_spec::runtime::Process

source ·
pub struct Process { /* private fields */ }
Process contains information to start a specific application inside the container.

Implementations

source

impl Process

source

pub fn terminal(&self) -> Option<bool>

Terminal creates an interactive terminal for the container.

source

pub fn console_size(&self) -> Option<Box>

ConsoleSize specifies the size of the console.

source

pub fn no_new_privileges(&self) -> Option<bool>

NoNewPrivileges controls whether additional privileges could be gained by processes in the container.

source

pub fn oom_score_adj(&self) -> Option<i32>

Specify an oom_score_adj for the container.

source

impl Process

source

pub fn user(&self) -> &User

User specifies user information for the process.

source

pub fn args(&self) -> &Option<Vec<String>>

Args specifies the binary and arguments for the application to execute.

source

pub fn command_line(&self) -> &Option<String>

CommandLine specifies the full command line for the application to execute on Windows.

source

pub fn env(&self) -> &Option<Vec<String>>

Env populates the process environment for the process.

source

pub fn cwd(&self) -> &PathBuf

Cwd is the current working directory for the process and must be relative to the container’s root.

source

pub fn capabilities(&self) -> &Option<LinuxCapabilities>

Capabilities are Linux capabilities that are kept for the process.

source

pub fn rlimits(&self) -> &Option<Vec<LinuxRlimit>>

Rlimits specifies rlimit options to apply to the process.

source

pub fn apparmor_profile(&self) -> &Option<String>

ApparmorProfile specifies the apparmor profile for the container.

source

pub fn selinux_label(&self) -> &Option<String>

SelinuxLabel specifies the selinux context that the container process is run as.

source

pub fn io_priority(&self) -> &Option<LinuxIOPriority>

IOPriority contains the I/O priority settings for the cgroup.

source

pub fn scheduler(&self) -> &Option<Scheduler>

Scheduler specifies the scheduling attributes for a process

source

impl Process

source

pub fn set_terminal(&mut self, val: Option<bool>) -> &mut Self

Terminal creates an interactive terminal for the container.

source

pub fn set_console_size(&mut self, val: Option<Box>) -> &mut Self

ConsoleSize specifies the size of the console.

source

pub fn set_user(&mut self, val: User) -> &mut Self

User specifies user information for the process.

source

pub fn set_args(&mut self, val: Option<Vec<String>>) -> &mut Self

Args specifies the binary and arguments for the application to execute.

source

pub fn set_command_line(&mut self, val: Option<String>) -> &mut Self

CommandLine specifies the full command line for the application to execute on Windows.

source

pub fn set_env(&mut self, val: Option<Vec<String>>) -> &mut Self

Env populates the process environment for the process.

source

pub fn set_cwd(&mut self, val: PathBuf) -> &mut Self

Cwd is the current working directory for the process and must be relative to the container’s root.

source

pub fn set_capabilities(&mut self, val: Option<LinuxCapabilities>) -> &mut Self

Capabilities are Linux capabilities that are kept for the process.

source

pub fn set_rlimits(&mut self, val: Option<Vec<LinuxRlimit>>) -> &mut Self

Rlimits specifies rlimit options to apply to the process.

source

pub fn set_no_new_privileges(&mut self, val: Option<bool>) -> &mut Self

NoNewPrivileges controls whether additional privileges could be gained by processes in the container.

source

pub fn set_apparmor_profile(&mut self, val: Option<String>) -> &mut Self

ApparmorProfile specifies the apparmor profile for the container.

source

pub fn set_oom_score_adj(&mut self, val: Option<i32>) -> &mut Self

Specify an oom_score_adj for the container.

source

pub fn set_selinux_label(&mut self, val: Option<String>) -> &mut Self

SelinuxLabel specifies the selinux context that the container process is run as.

source

pub fn set_io_priority(&mut self, val: Option<LinuxIOPriority>) -> &mut Self

IOPriority contains the I/O priority settings for the cgroup.

source

pub fn set_scheduler(&mut self, val: Option<Scheduler>) -> &mut Self

Scheduler specifies the scheduling attributes for a process