Struct oci_spec::runtime::Solaris

source ·
pub struct Solaris { /* private fields */ }
Solaris contains platform-specific configuration for Solaris application containers.

Implementations

source

impl Solaris

source

pub fn milestone(&self) -> &Option<String>

SMF FMRI which should go “online” before we start the container process.

source

pub fn limitpriv(&self) -> &Option<String>

Maximum set of privileges any process in this container can obtain.

source

pub fn max_shm_memory(&self) -> &Option<String>

The maximum amount of shared memory allowed for this container.

source

pub fn anet(&self) -> &Option<Vec<SolarisAnet>>

Specification for automatic creation of network resources for this container.

source

pub fn capped_cpu(&self) -> &Option<SolarisCappedCPU>

Set limit on the amount of CPU time that can be used by container.

source

pub fn capped_memory(&self) -> &Option<SolarisCappedMemory>

The physical and swap caps on the memory that can be used by this container.

source

impl Solaris

source

pub fn set_milestone(&mut self, val: Option<String>) -> &mut Self

SMF FMRI which should go “online” before we start the container process.

source

pub fn set_limitpriv(&mut self, val: Option<String>) -> &mut Self

Maximum set of privileges any process in this container can obtain.

source

pub fn set_max_shm_memory(&mut self, val: Option<String>) -> &mut Self

The maximum amount of shared memory allowed for this container.

source

pub fn set_anet(&mut self, val: Option<Vec<SolarisAnet>>) -> &mut Self

Specification for automatic creation of network resources for this container.

source

pub fn set_capped_cpu(&mut self, val: Option<SolarisCappedCPU>) -> &mut Self

Set limit on the amount of CPU time that can be used by container.

source

pub fn set_capped_memory( &mut self, val: Option<SolarisCappedMemory> ) -> &mut Self

The physical and swap caps on the memory that can be used by this container.