pub struct SolarisAnet { /* private fields */ }
SolarisAnet provides the specification for automatic creation of network resources for this container.

Implementations

source

impl SolarisAnet

source

pub fn linkname(&self) -> &Option<String>

Specify a name for the automatically created VNIC datalink.

Specify the link over which the VNIC will be created.

source

pub fn allowed_address(&self) -> &Option<String>

The set of IP addresses that the container can use.

source

pub fn configure_allowed_address(&self) -> &Option<String>

Specifies whether allowedAddress limitation is to be applied to the VNIC.

source

pub fn defrouter(&self) -> &Option<String>

The value of the optional default router.

Enable one or more types of link protection.

source

pub fn mac_address(&self) -> &Option<String>

Set the VNIC’s macAddress.

source

impl SolarisAnet

source

pub fn set_linkname(&mut self, val: Option<String>) -> &mut Self

Specify a name for the automatically created VNIC datalink.

Specify the link over which the VNIC will be created.

source

pub fn set_allowed_address(&mut self, val: Option<String>) -> &mut Self

The set of IP addresses that the container can use.

source

pub fn set_configure_allowed_address( &mut self, val: Option<String> ) -> &mut Self

Specifies whether allowedAddress limitation is to be applied to the VNIC.

source

pub fn set_defrouter(&mut self, val: Option<String>) -> &mut Self

The value of the optional default router.

Enable one or more types of link protection.

source

pub fn set_mac_address(&mut self, val: Option<String>) -> &mut Self

Set the VNIC’s macAddress.