pub struct SolarisCappedMemory { /* private fields */ }
SolarisCappedMemory allows users to set the physical and swap caps on the memory that can be used by this container.

Implementations

source

impl SolarisCappedMemory

source

pub fn physical(&self) -> &Option<String>

The physical caps on the memory.

source

pub fn swap(&self) -> &Option<String>

The swap caps on the memory.

source

impl SolarisCappedMemory

source

pub fn set_physical(&mut self, val: Option<String>) -> &mut Self

The physical caps on the memory.

source

pub fn set_swap(&mut self, val: Option<String>) -> &mut Self

The swap caps on the memory.