pub struct VMHypervisor { /* private fields */ }
VMHypervisor contains information about the hypervisor to use for a virtual machine.

Implementations

source

impl VMHypervisor

source

pub fn path(&self) -> &PathBuf

Path is the host path to the hypervisor used to manage the virtual machine.

source

pub fn parameters(&self) -> &Option<Vec<String>>

Parameters specifies parameters to pass to the hypervisor.

source

impl VMHypervisor

source

pub fn set_path(&mut self, val: PathBuf) -> &mut Self

Path is the host path to the hypervisor used to manage the virtual machine.

source

pub fn set_parameters(&mut self, val: Option<Vec<String>>) -> &mut Self

Parameters specifies parameters to pass to the hypervisor.