Struct oci_spec::runtime::VMKernel

source ·
pub struct VMKernel { /* private fields */ }
VMKernel contains information about the kernel to use for a virtual machine.

Implementations

source

impl VMKernel

source

pub fn path(&self) -> &PathBuf

Path is the host path to the kernel used to boot the virtual machine.

source

pub fn parameters(&self) -> &Option<Vec<String>>

Parameters specifies parameters to pass to the kernel.

source

pub fn initrd(&self) -> &Option<String>

InitRD is the host path to an initial ramdisk to be used by the kernel.

source

impl VMKernel

source

pub fn set_path(&mut self, val: PathBuf) -> &mut Self

Path is the host path to the kernel used to boot the virtual machine.

source

pub fn set_parameters(&mut self, val: Option<Vec<String>>) -> &mut Self

Parameters specifies parameters to pass to the kernel.

source

pub fn set_initrd(&mut self, val: Option<String>) -> &mut Self

InitRD is the host path to an initial ramdisk to be used by the kernel.