Struct oci_spec::runtime::Windows

source ·
pub struct Windows { /* private fields */ }
Windows defines the runtime configuration for Windows based containers, including Hyper-V containers.

Implementations

source

impl Windows

source

pub fn resources(&self) -> Option<WindowsResources>

Resources contains information for handling resource constraints for the container.

source

pub fn servicing(&self) -> Option<bool>

Servicing indicates if the container is being started in a mode to apply a Windows Update servicing operation.

source

pub fn ignore_flushes_during_boot(&self) -> Option<bool>

IgnoreFlushesDuringBoot indicates if the container is being started in a mode where disk writes are not flushed during its boot process.

source

impl Windows

source

pub fn layer_folders(&self) -> &Option<Vec<String>>

LayerFolders contains a list of absolute paths to directories containing image layers.

source

pub fn devices(&self) -> &Option<Vec<WindowsDevice>>

Devices are the list of devices to be mapped into the container.

source

pub fn credential_spec(&self) -> &Option<HashMap<String, Option<Value>>>

CredentialSpec contains a JSON object describing a group Managed Service Account (gMSA) specification.

source

pub fn hyperv(&self) -> &Option<WindowsHyperV>

HyperV contains information for running a container with Hyper-V isolation.

source

pub fn network(&self) -> &Option<WindowsNetwork>

Network restriction configuration.

source

impl Windows

source

pub fn set_layer_folders(&mut self, val: Option<Vec<String>>) -> &mut Self

LayerFolders contains a list of absolute paths to directories containing image layers.

source

pub fn set_devices(&mut self, val: Option<Vec<WindowsDevice>>) -> &mut Self

Devices are the list of devices to be mapped into the container.

source

pub fn set_resources(&mut self, val: Option<WindowsResources>) -> &mut Self

Resources contains information for handling resource constraints for the container.

source

pub fn set_credential_spec( &mut self, val: Option<HashMap<String, Option<Value>>> ) -> &mut Self

CredentialSpec contains a JSON object describing a group Managed Service Account (gMSA) specification.

source

pub fn set_servicing(&mut self, val: Option<bool>) -> &mut Self

Servicing indicates if the container is being started in a mode to apply a Windows Update servicing operation.

source

pub fn set_ignore_flushes_during_boot(&mut self, val: Option<bool>) -> &mut Self

IgnoreFlushesDuringBoot indicates if the container is being started in a mode where disk writes are not flushed during its boot process.

source

pub fn set_hyperv(&mut self, val: Option<WindowsHyperV>) -> &mut Self

HyperV contains information for running a container with Hyper-V isolation.

source

pub fn set_network(&mut self, val: Option<WindowsNetwork>) -> &mut Self

Network restriction configuration.