pub struct WindowsHyperV { /* private fields */ }
WindowsHyperV contains information for configuring a container to run with Hyper-V isolation.

Implementations

source

impl WindowsHyperV

source

pub fn utility_vm_path(&self) -> &Option<String>

UtilityVMPath is an optional path to the image used for the Utility VM.

source

impl WindowsHyperV

source

pub fn set_utility_vm_path(&mut self, val: Option<String>) -> &mut Self

UtilityVMPath is an optional path to the image used for the Utility VM.