pub struct WindowsNetwork { /* private fields */ }
WindowsNetwork contains network settings for Windows containers.

Implementations

source

impl WindowsNetwork

source

pub fn endpoint_list(&self) -> &Option<Vec<String>>

List of HNS endpoints that the container should connect to.

source

pub fn dns_search_list(&self) -> &Option<Vec<String>>

Comma separated list of DNS suffixes to use for name resolution.

source

pub fn network_shared_container_name(&self) -> &Option<String>

Name (ID) of the container that we will share with the network stack.

source

pub fn network_namespace(&self) -> &Option<String>

name (ID) of the network namespace that will be used for the container.

source

impl WindowsNetwork

source

pub fn set_endpoint_list(&mut self, val: Option<Vec<String>>) -> &mut Self

List of HNS endpoints that the container should connect to.

source

pub fn set_allow_unqualified_dns_query( &mut self, val: Option<bool> ) -> &mut Self

Specifies if unqualified DNS name resolution is allowed.

source

pub fn set_dns_search_list(&mut self, val: Option<Vec<String>>) -> &mut Self

Comma separated list of DNS suffixes to use for name resolution.

source

pub fn set_network_shared_container_name( &mut self, val: Option<String> ) -> &mut Self

Name (ID) of the container that we will share with the network stack.

source

pub fn set_network_namespace(&mut self, val: Option<String>) -> &mut Self

name (ID) of the network namespace that will be used for the container.