pub struct ZOSNamespaceBuilder { /* private fields */ }Expand description
Builder for ZOSNamespace.
Implementations
Sourceimpl ZOSNamespaceBuilder
impl ZOSNamespaceBuilder
Sourcepub fn typ<VALUE: Into<ZOSNamespaceType>>(self, value: VALUE) -> Self
pub fn typ<VALUE: Into<ZOSNamespaceType>>(self, value: VALUE) -> Self
Type is the type of namespace.
Sourcepub fn path<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
pub fn path<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
Path is a path to an existing namespace persisted on disk that can be joined and is of the same type
Sourcepub fn build(self) -> Result<ZOSNamespace, OciSpecError>
pub fn build(self) -> Result<ZOSNamespace, OciSpecError>