Struct oci_spec::image::Descriptor [−][src]
pub struct Descriptor {
pub media_type: String,
pub digest: String,
pub size: i64,
pub urls: Option<Vec<String>>,
pub annotations: Option<HashMap<String, String>>,
pub platform: Option<Platform>,
}Expand description
A Content Descriptor (or simply Descriptor) describes the disposition of the targeted content. It includes the type of the content, a content identifier (digest), and the byte-size of the raw content. Descriptors SHOULD be embedded in other formats to securely reference external content.
Fields
media_type: StringThis REQUIRED property contains the media type of the referenced content. Values MUST comply with RFC 6838, including the naming requirements in its section 4.2.
digest: StringThis REQUIRED property is the digest of the targeted content, conforming to the requirements outlined in Digests. Retrieved content SHOULD be verified against this digest when consumed via untrusted sources.
size: i64This REQUIRED property specifies the size, in bytes, of the raw content. This property exists so that a client will have an expected size for the content before processing. If the length of the retrieved content does not match the specified length, the content SHOULD NOT be trusted.
urls: Option<Vec<String>>This OPTIONAL property specifies a list of URIs from which this object MAY be downloaded. Each entry MUST conform to RFC 3986. Entries SHOULD use the http and https schemes, as defined in RFC 7230.
annotations: Option<HashMap<String, String>>This OPTIONAL property contains arbitrary metadata for this descriptor. This OPTIONAL property MUST use the annotation rules.
platform: Option<Platform>This OPTIONAL property describes the minimum runtime requirements of the image. This property SHOULD be present if its target is platform-specific.