Enum oci_spec::runtime::Arch

source ·
pub enum Arch {
Show 17 variants ScmpArchNative = 0, ScmpArchX86 = 1_073_741_827, ScmpArchX86_64 = -1_073_741_762, ScmpArchX32 = 1_073_741_886, ScmpArchArm = 1_073_741_864, ScmpArchAarch64 = -1_073_741_641, ScmpArchMips = 8, ScmpArchMips64 = -2_147_483_640, ScmpArchMips64n32 = -1_610_612_728, ScmpArchMipsel = 1_073_741_832, ScmpArchMipsel64 = -1_073_741_816, ScmpArchMipsel64n32 = -536_870_904, ScmpArchPpc = 20, ScmpArchPpc64 = -2_147_483_627, ScmpArchPpc64le = -1_073_741_803, ScmpArchS390 = 22, ScmpArchS390x = -2_147_483_626,
}
Available seccomp architectures.

Variants



ScmpArchNative = 0

The native architecture.



ScmpArchX86 = 1_073_741_827

The x86 (32-bit) architecture.



ScmpArchX86_64 = -1_073_741_762

The x86-64 (64-bit) architecture.



ScmpArchX32 = 1_073_741_886

The x32 (32-bit x86_64) architecture.

This is different from the value used by the kernel because we need to be able to distinguish between x32 and x86_64.



ScmpArchArm = 1_073_741_864

The ARM architecture.



ScmpArchAarch64 = -1_073_741_641

The AArch64 architecture.



ScmpArchMips = 8

The MIPS architecture.



ScmpArchMips64 = -2_147_483_640

The MIPS64 architecture.



ScmpArchMips64n32 = -1_610_612_728

The MIPS64n32 architecture.



ScmpArchMipsel = 1_073_741_832

The MIPSel architecture.



ScmpArchMipsel64 = -1_073_741_816

The MIPSel64 architecture.



ScmpArchMipsel64n32 = -536_870_904

The MIPSel64n32 architecture.



ScmpArchPpc = 20

The PowerPC architecture.



ScmpArchPpc64 = -2_147_483_627

The PowerPC64 architecture.



ScmpArchPpc64le = -1_073_741_803

The PowerPC64le architecture.



ScmpArchS390 = 22

The S390 architecture.



ScmpArchS390x = -2_147_483_626

The S390x architecture.