Struct oci_spec::runtime::Windows[][src]

pub struct Windows {
    pub layer_folders: Vec<String>,
    pub devices: Option<Vec<WindowsDevice>>,
    pub resources: Option<WindowsResources>,
    pub credential_spec: Option<HashMap<String, Option<Value>>>,
    pub servicing: Option<bool>,
    pub ignore_flushes_during_boot: Option<bool>,
    pub hyperv: Option<WindowsHyperV>,
    pub network: Option<WindowsNetwork>,
}
Windows defines the runtime configuration for Windows based containers, including Hyper-V containers.

Fields

layer_folders: Vec<String>

LayerFolders contains a list of absolute paths to directories containing image layers.

devices: Option<Vec<WindowsDevice>>

Devices are the list of devices to be mapped into the container.

resources: Option<WindowsResources>

Resources contains information for handling resource constraints for the container.

credential_spec: Option<HashMap<String, Option<Value>>>

CredentialSpec contains a JSON object describing a group Managed Service Account (gMSA) specification.

servicing: Option<bool>

Servicing indicates if the container is being started in a mode to apply a Windows Update servicing operation.

ignore_flushes_during_boot: Option<bool>

IgnoreFlushesDuringBoot indicates if the container is being started in a mode where disk writes are not flushed during its boot process.

hyperv: Option<WindowsHyperV>

HyperV contains information for running a container with Hyper-V isolation.

network: Option<WindowsNetwork>

Network restriction configuration.